=========
Xdatasets
=========

.. image:: https://img.shields.io/pypi/v/xdatasets.svg
        :target: https://pypi.python.org/pypi/xdatasets
        :alt: PyPI

.. image:: https://github.com/hydrologie/xdatasets/actions/workflows/main.yml/badge.svg
        :target: https://github.com/hydrologie/xdatasets/actions
        :alt: Build Status

.. image:: https://readthedocs.org/projects/xdatasets/badge/?version=latest
        :target: https://xdatasets.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/github/license/hydrologie/xdatasets.svg
        :target: https://github.com/hydrologie/xdatasets/blob/master/LICENSE
        :alt: License

Easy access to Earth observation datasets with xarray.

* Free software: MIT license
* Documentation: https://xdatasets.github.io/xdatasets

Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `Ouranosinc/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/cookiecutter/cookiecutter
.. _`Ouranosinc/cookiecutter-pypackage`: https://github.com/Ouranosinc/cookiecutter-pypackage
